@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/freesp.c,v 1.21 2004/11/13 20:38:40 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/freesp.c,v 1.23 2007/04/01 13:33:36 werner Exp $
  *
  * Ermittlung der freien Plattenkapazitaet
  *
@@ -19,7 +19,7 @@
 #if defined( SVR4 ) || defined( OSF1 ) || defined( sun56 )
 #include <sys/statvfs.h>
 #else
-#if ( defined( ultrix ) || defined(openbsd) || defined ( __FreeBSD__ ) || defined (__APPLE__) )
+#if ( defined( ultrix ) || defined( __OpenBSD__ ) || defined(__NetBSD__) || defined ( __FreeBSD__ ) || defined (__APPLE__) )
 #include <sys/param.h>
 #include <sys/mount.h>
 #else
@@ -204,11 +204,11 @@ int GetDiskParameter( char *path,
 #if defined( SVR4 ) || defined( OSF1 )
         fname = statfs_struct.f_fstr;
 #else
-#ifdef openbsd
+#if defined(__OpenBSD__) || defined(__NetBSD__)
         fname = statfs_struct.f_fstypename;
 #else
         fname = statfs_struct.f_fname;
-#endif /* openbsd */
+#endif /* __OpenBSD__ || __NetBSD__ */
 #endif /* SVR4 */
 #endif /* __DJGPP__ */
 #endif /* QNX */
