@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.39 2005/09/07 18:50:33 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.41 2007/04/01 13:33:36 werner Exp $
  *
  * Header-Datei fuer YTREE
  *
@@ -15,6 +15,10 @@
 #include <ctype.h>
 #include <math.h>
 
+#if defined(__OpenBSD__) || defined(__NetBSD__) || defined(__FreeBSD__) || defined(__NetBSD__)
+#include <locale.h>
+#endif
+
 #ifdef XCURSES
 #include <xcurses.h>
 #define HAVE_CURSES 1
@@ -83,7 +87,7 @@ extern char *getcwd();
 #include <wchar.h>
 #endif
 
-#ifdef openbsd
+#if defined(__OpenBSD__) || defined(__NetBSD__)
 #define STATFS(a, b, c, d )     statfs( a, b )
 #define LONGLONG		long long
 #define HAS_LONGLONG		1
@@ -156,7 +160,7 @@ extern char *getcwd();
 #endif /* OSF1 */
 #endif /* __APPLE__ */
 #endif /* __FreeBSD__ */
-#endif /* openbsd */
+#endif /* __OpenBSD__ || __NetBSD__ */
 
 
 /* Some handy macros... */
